%global game    OpenRA
%global tarball release-%{version}
%global folder  %{game}-%{tarball}

%global editor  %{name}-editor

##https://fedoraproject.org/wiki/Packaging:Mono?rd=Packaging/Mono#File_Locations
%global gamedir %{_prefix}/lib/%{name}

Name:           openra
Version:        20141029
Release:        1%{?dist}
Summary:        Libre/Free Real Time Strategy project 

License:        GPLv3+
URL:            http://openra.net
Source0:        https://github.com/%{game}/%{game}/archive/%{tarball}.tar.gz#/%{folder}.tar.gz

BuildArch:      noarch

BuildRequires:  mono-devel desktop-file-utils

Requires:       hicolor-icon-theme
Requires:       gnu-free-sans-fonts

Requires:       %{name}-libs  = %{version}-%{release}
Requires:       %{name}-fonts = %{version}-%{release}
Requires:       %{name}-mod   = %{version}-%{release}

##Upstream forces to use compatibility layer, see also rhbz #1111013
##http://www.redhat.com/archives/rhl-devel-list/2008-March/msg00314.html
BuildRequires:  compat-lua-devel

##Dependencies from original upstream spec file
Requires: mono-core
Requires: mono-winforms
Requires: openal
Requires: libfreetype.so.6
Requires: libasound.so.2
Requires: libc.so.6
Requires: libdl.so.2
Requires: libm.so.6
Requires: libpthread.so.0
Requires: librt.so.1
Requires: xdg-utils
Requires: zenity


%description
%{game} is a Libre/Free Real Time Strategy project that recreates
the famous Command & Conquer titles.

Available mods: C&C (Tiberian Dawn), C&C: Red Alert, and Dune 2000.
These are not intended to be perfect copies, but instead combine the classic
game-play of the originals with modern improvements such as unit veterancy
and the fog of war.

%{game}'s primary focus is cross-platform multiplayer between Windows, OS X,
and Linux; however, we include a number of single-player missions, and also
support skirmish games against AI bots.



%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
Libraries, header files and API documentation for developing mods of %{game}.


%package        editor
Summary:        Editor for %{name}
Requires:       %{name} = %{version}-%{release}

%description    editor
The editor for the game %{game}.


%package        fonts
Summary:        Fonts for %{name}
Requires:       %{name}-libs = %{version}-%{release}

%description    fonts
Fonts commonly used in the game %{game}. Includes the common bundles.


%package        libs
Summary:        Common library files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    libs
Common library files for modding of %{game}.


%package        mod-cnc
Summary:        Tiberian Dawn mod for %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-mod

%description    mod-cnc
The mod Tiberian Dawn for the game %{game}.


%package        mod-d2k
Summary:        Dune 2000 mod for %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-mod

%description    mod-d2k
The mod Dune 2000 for the game %{game}.


%package        mod-ra
Summary:        Red Alert mod for %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-mod

%description    mod-ra
The mod Red Alert for the game %{game}.


%package        mod-ts
Summary:        Tiberian Sun mod for %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-mod

%description    mod-ts
The (upcoming) mod Tiberian Sun for the game %{game}.

%prep
%setup -qn%{folder}
##unbundle and useless thirdparty
#find thirdparty -type d |xargs rm -r
make version


%build
%configure
make %{?_smp_mflags} all
##docs, make after all is built
make %{?_smp_mflags} docs


%check
make %{?_smp_mflags} test


%clean
make DESTDIR="%{buildroot}" prefix=%{_prefix} uninstall


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%install
##FIXME missing licenses: https://github.com/OpenRA/OpenRA/issues/6862
%make_install prefix=%{_prefix} bindir=%{_bindir} \
 gameinstalldir=%{gamedir} \
 install-all install-linux-shortcuts 
 
##fix non-standard-executable-perm 0555L
chmod 0755 %{buildroot}%{_bindir}/*

##fonts unbundle
cd %{buildroot}%{gamedir}/mods/common
find . -name '*.ttf' -exec 'rm {} ; ln -s ../../../fonts/{} {}' \;

##desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop

##misplacements
cd %{buildroot}%{gamedir}
rm AUTHORS COPYING


%files
%doc AUTHORS COPYING CONTRIBUTING.md README.md
%{_bindir}/%{name}
%dir %{gamedir}
%{gamedir}/%{game}.Game.exe
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}.svg

%files devel
%doc DOCUMENTATION.md Lua-API.md
%{gamedir}/%{game}.Lint.exe
%{gamedir}/%{game}.Utility.exe

%files editor
%{_bindir}/%{editor}
%{gamedir}/%{game}.Editor.exe
%{_datadir}/applications/%{editor}.desktop
%{_datadir}/icons/hicolor/*/apps/%{editor}.png

%files fonts
%{gamedir}/mods/common/*.ttf

%files libs
%dir %{gamedir}
%{gamedir}/*.dll
%{gamedir}/*.dll.config
%{gamedir}/*.mmdb
%{gamedir}/*.dat
%{gamedir}/*.sh
%{gamedir}/glsl/
%{gamedir}/lua/
%dir %{gamedir}/mods
%{gamedir}/mods/modchooser/
%dir %{gamedir}/mods/common
%{gamedir}/mods/common/*.dll
%{gamedir}/mods/common/*.dll.mdb

%files mod-cnc
%{gamedir}/mods/cnc/

%files mod-d2k
%{gamedir}/mods/d2k/

%files mod-ra
%{gamedir}/mods/ra/

%files mod-ts
##<antares79> on purpose, it's not production-ready yet
#%{gamedir}/mods/ts/


%changelog
* Thu Oct 30 2014 Raphael Groner <projects.rg [AT] smart.ms> - 20141029-1
- based on original spec from upstream and build.opensuse.org
- cleanup to comply with policy
- current lua (v5.2+) is not supported at upstream
- include tools
- split data, editor, fonts and mods into subpackages
